@@ -1,7 +1,7 @@
 from .config import (
     __all__ as config_all,
     Configuration, Logger_configuration, Env_vars )
-from .logger import *  # noqa
+from .logger import *  # NOQA
 from chibi.file import Chibi_path
 
 
@@ -24,12 +24,14 @@ def default_file_load():
         config_home = Chibi_path( '~/.config' )
 
     config_home += 'chibi'
-    if not config_home.exists:
-        config_home.mkdir()
-
     config_file = config_home + 'chibi.py'
+    if not config_home.exists:
+        return
+        # config_home.mkdir()
+
     if not config_file.exists:
-        config_file.touch()
+        return
+        # config_file.touch()
     load( config_file )
 
 
